@@ -1,3 +1,4 @@
+#include <unicode/umachine.h>
 
 #define MAX_TAGNAMELENGTH 20
 #define MAX_STRIPTAGS 20
@@ -27,15 +28,16 @@ typedef struct Stripper {
   int numstriptags;
   int o_emit_spaces;
   int o_decode_entities;
+  int o_utf8;
 
   int o_auto_reset;
 
   int o_debug;
 } Stripper;
 
-void strip_html( Stripper * stripper, const char * raw, char * clean );
+void strip_html( Stripper * stripper, UChar * raw, UChar * clean );
 void reset( Stripper * stripper );
 void clear_striptags( Stripper * stripper );
 void add_striptag( Stripper * stripper, char * tag );
 
-void check_end( Stripper * stripper, char );
+void check_end( Stripper * stripper, UChar );
